---
layout: post
permalink: /libs/{{name}}/
title: {{name}}.dots
---

### Purpose
This librairy...

### Usage
    
     T
    L+R
     B

##### Parameters
- `L`: 
- `R`: 
- `T`: 
- `B`: 

##### Example

    %![name].dots W

##### Output

    42
   

### Notes
- 
-

### Source 
The source code is availaible [here](https://github.com/aaronjanse/asciidots/blob/master/dots/libs/{{name}}.dots)
. If something doesn't work, do not hesitate to [open an issue](https://github.com/aaronjanse/asciidots/issues/new?title=Bug%20in%20{{name}}%20library:%20).

